[−][src]Enum unicode_types::malayalam::Malayalam
An enum to represent all characters in the Malayalam block.
Variants
SignCombiningAnusvaraAbove\u{d00}: 'ഀ'
SignCandrabindu\u{d01}: 'ഁ'
SignAnusvara\u{d02}: 'ം'
SignVisarga\u{d03}: 'ഃ'
LetterA\u{d05}: 'അ'
LetterAa\u{d06}: 'ആ'
LetterI\u{d07}: 'ഇ'
LetterIi\u{d08}: 'ഈ'
LetterU\u{d09}: 'ഉ'
LetterUu\u{d0a}: 'ഊ'
LetterVocalicR\u{d0b}: 'ഋ'
LetterVocalicL\u{d0c}: 'ഌ'
LetterE\u{d0e}: 'എ'
LetterEe\u{d0f}: 'ഏ'
LetterAi\u{d10}: 'ഐ'
LetterO\u{d12}: 'ഒ'
LetterOo\u{d13}: 'ഓ'
LetterAu\u{d14}: 'ഔ'
LetterKa\u{d15}: 'ക'
LetterKha\u{d16}: 'ഖ'
LetterGa\u{d17}: 'ഗ'
LetterGha\u{d18}: 'ഘ'
LetterNga\u{d19}: 'ങ'
LetterCa\u{d1a}: 'ച'
LetterCha\u{d1b}: 'ഛ'
LetterJa\u{d1c}: 'ജ'
LetterJha\u{d1d}: 'ഝ'
LetterNya\u{d1e}: 'ഞ'
LetterTta\u{d1f}: 'ട'
LetterTtha\u{d20}: 'ഠ'
LetterDda\u{d21}: 'ഡ'
LetterDdha\u{d22}: 'ഢ'
LetterNna\u{d23}: 'ണ'
LetterTa\u{d24}: 'ത'
LetterTha\u{d25}: 'ഥ'
LetterDa\u{d26}: 'ദ'
LetterDha\u{d27}: 'ധ'
LetterNa\u{d28}: 'ന'
LetterNnna\u{d29}: 'ഩ'
LetterPa\u{d2a}: 'പ'
LetterPha\u{d2b}: 'ഫ'
LetterBa\u{d2c}: 'ബ'
LetterBha\u{d2d}: 'ഭ'
LetterMa\u{d2e}: 'മ'
LetterYa\u{d2f}: 'യ'
LetterRa\u{d30}: 'ര'
LetterRra\u{d31}: 'റ'
LetterLa\u{d32}: 'ല'
LetterLla\u{d33}: 'ള'
LetterLlla\u{d34}: 'ഴ'
LetterVa\u{d35}: 'വ'
LetterSha\u{d36}: 'ശ'
LetterSsa\u{d37}: 'ഷ'
LetterSa\u{d38}: 'സ'
LetterHa\u{d39}: 'ഹ'
LetterTtta\u{d3a}: 'ഺ'
SignVerticalBarVirama\u{d3b}: '഻'
SignCircularVirama\u{d3c}: '഼'
SignAvagraha\u{d3d}: 'ഽ'
VowelSignAa\u{d3e}: 'ാ'
VowelSignI\u{d3f}: 'ി'
VowelSignIi\u{d40}: 'ീ'
VowelSignU\u{d41}: 'ു'
VowelSignUu\u{d42}: 'ൂ'
VowelSignVocalicR\u{d43}: 'ൃ'
VowelSignVocalicRr\u{d44}: 'ൄ'
VowelSignE\u{d46}: 'െ'
VowelSignEe\u{d47}: 'േ'
VowelSignAi\u{d48}: 'ൈ'
VowelSignO\u{d4a}: 'ൊ'
VowelSignOo\u{d4b}: 'ോ'
VowelSignAu\u{d4c}: 'ൌ'
SignVirama\u{d4d}: '്'
LetterDotReph\u{d4e}: 'ൎ'
SignPara\u{d4f}: '൏'
LetterChilluM\u{d54}: 'ൔ'
LetterChilluY\u{d55}: 'ൕ'
LetterChilluLll\u{d56}: 'ൖ'
AuLengthMark\u{d57}: 'ൗ'
FractionOneOneDashHundredDashAndDashSixtieth\u{d58}: '൘'
FractionOneFortieth\u{d59}: '൙'
FractionThreeEightieths\u{d5a}: '൚'
FractionOneTwentieth\u{d5b}: '൛'
FractionOneTenth\u{d5c}: '൜'
FractionThreeTwentieths\u{d5d}: '൝'
FractionOneFifth\u{d5e}: '൞'
LetterArchaicIi\u{d5f}: 'ൟ'
LetterVocalicRr\u{d60}: 'ൠ'
LetterVocalicLl\u{d61}: 'ൡ'
VowelSignVocalicL\u{d62}: 'ൢ'
VowelSignVocalicLl\u{d63}: 'ൣ'
DigitZero\u{d66}: '൦'
DigitOne\u{d67}: '൧'
DigitTwo\u{d68}: '൨'
DigitThree\u{d69}: '൩'
DigitFour\u{d6a}: '൪'
DigitFive\u{d6b}: '൫'
DigitSix\u{d6c}: '൬'
DigitSeven\u{d6d}: '൭'
DigitEight\u{d6e}: '൮'
DigitNine\u{d6f}: '൯'
NumberTen\u{d70}: '൰'
NumberOneHundred\u{d71}: '൱'
NumberOneThousand\u{d72}: '൲'
FractionOneQuarter\u{d73}: '൳'
FractionOneHalf\u{d74}: '൴'
FractionThreeQuarters\u{d75}: '൵'
FractionOneSixteenth\u{d76}: '൶'
FractionOneEighth\u{d77}: '൷'
FractionThreeSixteenths\u{d78}: '൸'
DateMark\u{d79}: '൹'
LetterChilluNn\u{d7a}: 'ൺ'
LetterChilluN\u{d7b}: 'ൻ'
LetterChilluRr\u{d7c}: 'ർ'
LetterChilluL\u{d7d}: 'ൽ'
LetterChilluLl\u{d7e}: 'ൾ'
Methods
impl Malayalam[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case